
#include <assert.h>
#include "bitmap.h"

// Time to look before shifting eyse back
const int LookTime = 500;

// Files that contain the eyes looking different directions
const string EyesUpFile = "eyesup.bmp";
const string EyesLeftFile = "eyesleft.bmp";
const string EyesStraightFile = "eyesst.bmp";
const string EyesRightFile = "eyesrt.bmp";
const string EyesDownFile = "eyesdn.bmp";

const float EyeHeightDistance    =  2.5;
const float CenterButtonDistance =  1.5;

const float WindowWidth = 10.0;
const float WindowHeight = 8.0;
const float WindowX = 5.0;
const float WindowY = 6.0;

SimpleWindow EyesWindow("Mister Eyes", WindowWidth, WindowHeight,
 Position(WindowX, WindowY));

// BitMap for the eyes
BitMap Eyes(EyesWindow);

// BitMaps for the five buttons
BitMap UpButton;
BitMap LeftButton;
BitMap CenterButton;
BitMap RightButton;
BitMap DownButton;

// DisplayEyes(): display the eyes looking ahead
void DisplayEyes(const Position &WindowCenter) {

   Eyes.Load(EyesStraightFile);
   assert(Eyes.GetStatus() == BitMapOkay);

   Position EyesLocation = WindowCenter + Position(-0.5 * Eyes.GetWidth(),
    -0.5 * Eyes.GetHeight() - EyeHeightDistance);
   Eyes.SetPosition(EyesLocation);
   Eyes.Draw();
}

void DisplayButtons(const Position &WindowCenter) {

   // files that contain the five different buttons
   const string UpButtonFile = "up.bmp";
   const string LeftButtonFile = "left.bmp";
   const string StopButtonFile = "center.bmp";
   const string RightButtonFile = "right.bmp";
   const string DownButtonFile = "down.bmp";

   // Load the arrow button bitmaps
   UpButton.Load(UpButtonFile);
   assert(UpButton.GetStatus() == BitMapOkay);

   LeftButton.Load(LeftButtonFile);
   assert(LeftButton.GetStatus() == BitMapOkay);

   CenterButton.Load(StopButtonFile);
   assert(CenterButton.GetStatus() == BitMapOkay);

   RightButton.Load(RightButtonFile);
   assert(RightButton.GetStatus() == BitMapOkay);

   DownButton.Load(DownButtonFile);
   assert(DownButton.GetStatus() == BitMapOkay);

   // Compute the button positions and display them
   Position CenterButtonLocation(WindowCenter +
    Position(-0.5 * CenterButton.GetWidth(),
    -0.5 * CenterButton.GetHeight() + CenterButtonDistance));

   UpButton.SetPosition(CenterButtonLocation +
    Position(0, -1 * CenterButton.GetHeight()));

   LeftButton.SetPosition(CenterButtonLocation +
    Position(-1 * CenterButton.GetWidth(), 0));

   CenterButton.SetPosition(CenterButtonLocation);
   RightButton.SetPosition(CenterButtonLocation +
   Position(CenterButton.GetWidth(), 0));

   DownButton.SetPosition(CenterButtonLocation +
    Position(0, CenterButton.GetHeight()));

   // Draw the buttons
   UpButton.Draw();
   LeftButton.Draw();
   CenterButton.Draw();
   RightButton.Draw();
   DownButton.Draw();
}

int LookStraight() {
   // Put your code here

   return 1;
}


// PressButton(): determine if a button has been pressed
//                and if so, display the eyes looking in
//                the corresponding direction
int PressButton(const Position &MouseLocation) {
   if (UpButton.IsInside(MouseLocation)) {
      Eyes.Load(EyesUpFile);
      assert(Eyes.GetStatus() == BitMapOkay);
   }
   else if (LeftButton.IsInside(MouseLocation)) {
      Eyes.Load(EyesLeftFile);
      assert(Eyes.GetStatus() == BitMapOkay);
   }
   else if (CenterButton.IsInside(MouseLocation)) {
      Eyes.Load(EyesStraightFile);
      assert(Eyes.GetStatus() == BitMapOkay);
   }
   else if (RightButton.IsInside(MouseLocation)) {
      Eyes.Load(EyesRightFile);
      assert(Eyes.GetStatus() == BitMapOkay);
   }
   else if (DownButton.IsInside(MouseLocation)) {
      Eyes.Load(EyesDownFile);
      assert(Eyes.GetStatus() == BitMapOkay);
   }
   Eyes.Draw();

   // Put your code here

   return 1;
}

int ApiMain() {

   // Open the window
   EyesWindow.Open();
   assert(EyesWindow.GetStatus() == WindowOpen);

   // Set each button to display in the EyesWindow
   UpButton.SetWindow(EyesWindow);
   LeftButton.SetWindow(EyesWindow);
   CenterButton.SetWindow(EyesWindow);
   RightButton.SetWindow(EyesWindow);
   DownButton.SetWindow(EyesWindow);

   // Display the eyes looking straight ahead
   DisplayEyes(EyesWindow.GetCenter());

   // Display the buttons
   DisplayButtons(EyesWindow.GetCenter());

   // Set the mouse click callback
   EyesWindow.SetMouseClickCallback(PressButton);
   return 0;
}


int ApiEnd() {

   EyesWindow.Close();
   return 0;
}
