//
// The mouse is used to demonstrate a simple mouse callback. When the
// mouse pointer is clicked on the picture of the card it flips.

#include <assert.h>
#include "bitmap.h"


enum Cards {down, jack, queen, king};
const string Down  = "cardbk1.bmp";
const string Jack  = "c11.bmp";
const string Queen = "c12.bmp";
const string King  = "c13.bmp";

const float WindowWidth = 6.0;
const float WindowHeight = 4.0;
const float WindowX = 5.0;
const float WindowY = 6.0;

// Instantiate a window
SimpleWindow BitMapWindow("A Window with a Bitmap",
 WindowWidth, WindowHeight, Position(WindowX, WindowY));

// Instantiate a bitmap to be displayed in the window
BitMap CardImage(BitMapWindow);

// Prototypes for card flipping functions
int FlipDown(const Position &);
int FlipJack(const Position &);
int FlipQueen(const Position &);
int FlipKing(const Position &);

void DisplayCard(const string &CardFileName) {
   // Load the image
   CardImage.Load(CardFileName);
   assert(CardImage.GetStatus() == BitMapOkay);
   // Draw the card at the current position
   CardImage.Draw();
   return;
}

int FlipDown(const Position &Location) {
   if (CardImage.IsInside(Location))
      DisplayCard(Down);
   return 1;
}

int FlipJack(const Position &Location) {
   if (CardImage.IsInside(Location))
      DisplayCard(Jack);
   return 1;
}

int FlipQueen(const Position &Location) {
   if (CardImage.IsInside(Location))
      DisplayCard(Queen);
   return 1;
}

int FlipKing(const Position &Location) {
   if (CardImage.IsInside(Location))
      DisplayCard(King);
   return 1;
}

int ApiMain() {
   // Open the window and get its center
   BitMapWindow.Open();
   assert(BitMapWindow.GetStatus() == WindowOpen);
   Position WindowCenter = BitMapWindow.GetCenter();

   // Load the card down image and display it
   CardImage.Load(Down);

   Position UpperLeftCorner = WindowCenter +
   Position(-0.5 * CardImage.GetWidth(), -0.5 * CardImage.GetHeight());
   CardImage.SetPosition(UpperLeftCorner);
   CardImage.Draw();

   BitMapWindow.SetMouseClickCallback(FlipQueen);

   return 0;
}


int ApiEnd() {
   BitMapWindow.Close();
   return 0;
};
