//**************************************************************************//
//                                                                          //
// Copyright (c) 1997.                                                      //
//      Richard D. Irwin, Inc.                                              //
//                                                                          //
// This software may not be distributed further without permission from     //
// Richard D. Irwin, Inc.                                                   //
//                                                                          //
// This software is distributed WITHOUT ANY WARRANTY. No claims are made    //
// as to its functionality or purpose.                                      //
//                                                                          //
// Authors: James P. Cohoon and Jack W. Davidson                            //
// Date: 7/15/96                                                            //
// Version: 1.0b                                                            //
//                                                                          //
// Edited by: Devon                                                         //
// Date:      7/23/96                                                       //
// Changes:   The program is a simplification of the original program       //
//            which displayed two windows and two bitmaps.                  //
//**************************************************************************//

// Example showing use of timer events
// The program displays a bitmap in the window at
// a random location when the timer goes off

#include <assert.h>
#include "bitmap.h"
#include "randint.h"

const float WindowWidth = 15.0;
const float WindowHeight = 9.0;
const float WindowX = 1.0;
const float WindowY = 1.0;

// Instantiate a window
SimpleWindow EyeWindow("I'm Watching You!", WindowWidth, WindowHeight,
 Position(WindowX, WindowY));

// Instantiate a bitmap for display in window EyeWindow
BitMap EyeBmp(EyeWindow);

int EyeWindowTimerEvent() {
   RandomInt RandomX(1, (int) EyeWindow.GetWidth());
   int XCoord = RandomX.Draw();

   RandomInt RandomY(1, (int) EyeWindow.GetHeight());
   int YCoord = RandomY.Draw();

   EyeBmp.Erase();
   if (XCoord + EyeBmp.GetWidth()  > EyeWindow.GetWidth() )
    XCoord = XCoord - EyeBmp.GetWidth();
   if (YCoord + EyeBmp.GetHeight() > EyeWindow.GetHeight())
    YCoord = YCoord - EyeBmp.GetHeight();

   EyeBmp.SetPosition(Position(XCoord, YCoord));
   EyeBmp.Draw();
   return 1;
}

int ApiMain() {

   // Initialize the random number generator
   EzRandomize();
   EyeWindow.Open();
   assert(EyeWindow.GetStatus() == WindowOpen);

   EyeBmp.Load("bigeyes.bmp");
   assert(EyeBmp.GetStatus() == BitMapOkay);
   EyeBmp.SetPosition(Position(1.0, 1.0));
   EyeBmp.Draw();

   EyeWindow.SetTimerCallback(EyeWindowTimerEvent);

   EyeWindow.StartTimer(500);
   return 0;
}

// User is shutting down the program
int ApiEnd() {
   EyeWindow.StopTimer();
   EyeWindow.Close();
   return 0;
}

